@@ -1,11 +1,10 @@
 use mycobot::*;
 use std::env;
-use std::io;
 
-pub fn main() -> Result<(), io::Error> {
+pub fn main() -> Result<()> {
     let args: Vec<String> = env::args().skip(1).collect();
     let mut mycobot = MyCobotSerialOperator::new(&args[0], 115200);
-    let target = vec![-80.0, -10.0, -130.0, 70.0, 0.0, 0.0];
+    let target = [-80.0, -10.0, -130.0, 70.0, 0.0, 0.0];
     mycobot.set_color(255, 0, 0)?;
     mycobot.sync_send_angles(&target, 50, 3.0)?;
     let mut coords = mycobot.get_coords()?;
