@@ -1,11 +1,11 @@
-use std::io;
+use anyhow::Result;
 use std::thread;
 use std::time::Duration;
 
 pub trait Connection {
-    fn write(&mut self, command: &[u8]) -> Result<(), io::Error>;
-    fn read(&mut self) -> Result<Vec<u8>, io::Error>;
-    fn write_and_read(&mut self, command: &[u8]) -> Result<Vec<u8>, io::Error>;
+    fn write(&mut self, command: &[u8]) -> Result<()>;
+    fn read(&mut self) -> Result<Vec<u8>>;
+    fn write_and_read(&mut self, command: &[u8]) -> Result<Vec<u8>>;
 }
 
 pub struct Serial {
@@ -23,12 +23,12 @@ impl Serial {
 }
 
 impl Connection for Serial {
-    fn write(&mut self, command: &[u8]) -> Result<(), io::Error> {
+    fn write(&mut self, command: &[u8]) -> Result<()> {
         self.port.write_all(command)?;
         thread::sleep(Duration::from_millis(50));
         Ok(())
     }
-    fn read(&mut self) -> Result<Vec<u8>, io::Error> {
+    fn read(&mut self) -> Result<Vec<u8>> {
         let mut data = Vec::<u8>::new();
         loop {
             let mut buf = vec![0u8; 1];
@@ -39,7 +39,7 @@ impl Connection for Serial {
         }
         Ok(data)
     }
-    fn write_and_read(&mut self, command: &[u8]) -> Result<Vec<u8>, io::Error> {
+    fn write_and_read(&mut self, command: &[u8]) -> Result<Vec<u8>> {
         self.write(command)?;
         let res = self.read()?;
         Ok(res)
